@@ -2,8 +2,6 @@
 import ConfigParser
 import sys
 
-g_burpport = 4972
-g_burphost = '127.0.0.1'
 g_port = 5000
 g_bind = '::'
 g_refresh = 15
@@ -19,7 +17,7 @@ class Server:
         self.app = app
 
     def setup(self, conf=None):
-        global g_refresh, g_burpport, g_burphost, g_port, g_bind, g_ssl, g_sslcert, g_sslkey, g_version, g_auth
+        global g_refresh, g_port, g_bind, g_ssl, g_sslcert, g_sslkey, g_version, g_auth
         self.sslcontext = None
         if not conf:
             conf = self.app.config['CFG']
@@ -27,14 +25,12 @@ class Server:
         if not conf:
             raise IOError('No configuration file found')
 
-        config = ConfigParser.ConfigParser({'bport': g_burpport, 'bhost': g_burphost, 'port': g_port,
-                    'bind': g_bind, 'refresh': g_refresh, 'ssl': g_ssl, 'sslcert': g_sslcert,
+        config = ConfigParser.ConfigParser({'port': g_port,'bind': g_bind,
+                    'refresh': g_refresh, 'ssl': g_ssl, 'sslcert': g_sslcert,
                     'sslkey': g_sslkey, 'version': g_version, 'auth': g_auth})
         with open(conf) as fp:
             config.readfp(fp)
             try:
-                self.burpport = config.getint('Global', 'bport')
-                self.burphost = config.get('Global', 'bhost')
                 self.port = config.getint('Global', 'port')
                 self.bind = config.get('Global', 'bind')
                 self.vers = config.getint('Global', 'version')
@@ -45,20 +41,23 @@ class Server:
                     self.ssl = False
                 self.sslcert = config.get('Global', 'sslcert')
                 self.sslkey = config.get('Global', 'sslkey')
-                try:
-                    mod = __import__('burpui.misc.auth.{0}'.format(config.get('Global', 'auth')), fromlist=['UserHandler'])
-                    UserHandler = mod.UserHandler
-                    self.uhandler = UserHandler(self.app)
-                except Exception:
-                    self.app.logger.error('Import Exception, module \'%s\'', config.get('Global', 'auth'))
-                    sys.exit(1)
+                self.auth = config.get('Global', 'auth')
+                if self.auth != 'none':
+                    try:
+                        mod = __import__('burpui.misc.auth.{0}'.format(config.get('Global', 'auth')), fromlist=['UserHandler'])
+                        UserHandler = mod.UserHandler
+                        self.uhandler = UserHandler(self.app)
+                    except Exception, e:
+                        self.app.logger.error('Import Exception, module \'%s\': %s', config.get('Global', 'auth'), str(e))
+                        sys.exit(1)
+                else:
+                    # I know that's ugly, but hey, I need it!
+                    self.app.login_manager._login_disabled = True
             except ConfigParser.NoOptionError:
                 self.app.logger.error("Missing option")
 
             self.app.config['REFRESH'] = config.getint('UI', 'refresh')
 
-        self.app.logger.info('burp port: %d', self.burpport)
-        self.app.logger.info('burp host: %s', self.burphost)
         self.app.logger.info('burp version: %d', self.vers)
         self.app.logger.info('listen port: %d', self.port)
         self.app.logger.info('bind addr: %s', self.bind)
@@ -70,9 +69,9 @@ class Server:
         try:
             mod = __import__('burpui.misc.backend.burp{0}'.format(self.vers), fromlist=['Burp'])
             Client = mod.Burp
-            self.cli = Client(self.app, self.burphost, self.burpport)
-        except Exception:
-            self.app.logger.error('Failed loading backend for Burp version %d', self.vers)
+            self.cli = Client(self.app, conf=conf)
+        except Exception, e:
+            self.app.logger.error('Failed loading backend for Burp version %d: %s', self.vers, str(e))
             sys.exit(2)
 
         self.init = True
