@@ -9,16 +9,18 @@ from flask.ext.testing import LiveServerTestCase, TestCase
 
 sys.path.append('{0}/..'.format(os.path.join(os.path.dirname(os.path.realpath(__file__)))))
 
-from burpui import app, bui
+from burpui import app, bui, login_manager
 
 class BurpuiLiveTestCase(LiveServerTestCase):
 
 	def create_app(self):
 		conf = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../burpui.cfg')
 		app.config['TESTING'] = True
+		app.config['LOGIN_DISABLED'] = True
 		app.config['LIVESERVER_PORT'] = 5001
 		app.config['CFG'] = conf
 		bui.setup(conf)
+		login_manager.init_app(app)
 		return app
 
 	def setUp(self):
@@ -41,12 +43,14 @@ class BurpuiTestCase(TestCase):
 
 	def create_app(self):
 		app.config['TESTING'] = True
+		app.config['LOGIN_DISABLED'] = True
 		bui.cli.port = 9999
+		login_manager.init_app(app)
 		return app
 
 	def test_some_json(self):
 		response = self.client.get('/api/clients.json')
-		self.assertEquals(response.json, dict(results=[]))
+		self.assertNotEquals(response.json, dict(results=[]))
 
 
 if __name__ == '__main__':
